@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
-our $DATE = '2015-09-12'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2015-09-29'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use strict;
 use warnings;
@@ -18,7 +18,7 @@ sub import {
     my $caller = caller();
     my $i = 0;
     while ($i < @_) {
-        if ($_[$i] eq 'system' || $_[$i] eq 'backtick' || $_[$i] eq 'import') {
+        if ($_[$i] =~ /\A(system|backtick|run|import)\z/) {
             no strict 'refs';
             *{"$caller\::$_[$i]"} = \&{"$self\::" . $_[$i]};
         } elsif ($_[$i] =~ /\A-(.+)/) {
@@ -32,7 +32,7 @@ sub import {
     }
 }
 
-sub _system_or_backtick {
+sub _system_or_backtick_or_run {
     my $which = shift;
     my $opts = ref($_[0]) eq 'HASH' ? shift : {};
     for (keys %Global_Opts) {
@@ -110,7 +110,7 @@ sub _system_or_backtick {
         };
         $code_capture->($doit);
 
-    } else {
+    } elsif ($which eq 'backtick') {
 
         $wa = wantarray;
         my $cmd = join " ", @args;
@@ -155,6 +155,31 @@ sub _system_or_backtick {
                 unless $exit_code;
         }
 
+    } else {
+
+        $log->tracef("run(%s), env=%s", \@args, \%set_env) if $opts->{log};
+        require IPC::Run;
+        $res = IPC::Run::run(
+            \@args,
+            defined($opts->{stdin}) ? \$opts->{stdin} : \*STDIN,
+            sub {
+                if ($opts->{capture_stdout}) {
+                    ${$opts->{capture_stdout}} .= $_[0];
+                } else {
+                    print $_[0];
+                }
+            }, # out
+            sub {
+                if ($opts->{capture_stderr}) {
+                    ${$opts->{capture_stderr}} .= $_[0];
+                } else {
+                    print STDERR $_[0];
+                }
+            }, # err
+        );
+        $exit_code = $?;
+        $os_error = $!;
+
     } # which
 
     # restore ENV
@@ -178,10 +203,10 @@ sub _system_or_backtick {
                 explain_child_error($exit_code, $os_error),
                 (ref($opts->{capture_stdout}) ?
                      ", captured stdout: <<" .
-                     ${$opts->{capture_stdout}} . ">>" : ""),
+                     (${$opts->{capture_stdout}} // ''). ">>" : ""),
                 (ref($opts->{capture_stderr}) ?
                      ", captured stderr: <<" .
-                     ${$opts->{capture_stderr}} . ">>" : ""),
+                     (${$opts->{capture_stderr}} // ''). ">>" : ""),
             );
             $log->error($msg) if $opts->{log};
             croak $msg if $opt_die;
@@ -194,15 +219,19 @@ sub _system_or_backtick {
     $? = $exit_code;
     $! = $os_error;
 
-    return $wa ? @$res : $res;
+    return $wa && $which ne 'run' ? @$res : $res;
 }
 
 sub system {
-    _system_or_backtick('system', @_);
+    _system_or_backtick_or_run('system', @_);
 }
 
 sub backtick {
-    _system_or_backtick('backtick', @_);
+    _system_or_backtick_or_run('backtick', @_);
+}
+
+sub run {
+    _system_or_backtick_or_run('run', @_);
 }
 
 1;
@@ -220,11 +249,11 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.22 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-09-12.
+This document describes version 0.23 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-09-29.
 
 =head1 SYNOPSIS
 
- use IPC::System::Options qw(system backtick);
+ use IPC::System::Options qw(system backtick run);
 
  # use exactly like system()
  system(...);
@@ -249,6 +278,15 @@ Set default options for all calls (prefix each option with dash):
 
  use IPC::System::Options 'system', 'backtick', -log=>1, -die=>1;
 
+C<run()> is like C<system()> but uses L<IPC::Run>'s C<run()> instead of
+C<system()>:
+
+ run('ls');
+
+ # also accepts an optional hash first argument. some additional options that
+ # run() accepts: stdin.
+ run({capture_stdout => \$stdout, capture_stderr => \$stderr}, 'ls', '-l');
+
 =head1 DESCRIPTION
 
 =head1 FUNCTIONS
@@ -338,6 +376,42 @@ If set, will limit result length being logged. It's a good idea to set this
 
 =back
 
+=head2 run([ \%opts ], @args)
+
+Like C<system()>, but uses L<IPC::Run>'s C<run()>. Known options:
+
+=over
+
+=item * lang => str
+
+See option documentation in C<system()>.
+
+=item * env => hash
+
+See option documentation in C<system()>.
+
+=item * log => bool
+
+See option documentation in C<system()>.
+
+=item * die => bool
+
+See option documentation in C<system()>.
+
+=item * capture_stdout => scalarref
+
+See option documentation in C<system()>.
+
+=item * capture_stderr => scalarref
+
+See option documentation in C<system()>.
+
+=item * stdin => scalar
+
+Supply standard input.
+
+=back
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/IPC-System-Options>.
